[][src]Struct heed_types::integer::I128

#[repr(transparent)]pub struct I128<O: ByteOrder>(_, _);

A 128-bit signed integer stored in O byte order.

I128 is like the native i128 type with two major differences: First, it has no alignment requirement (its alignment is 1). Second, the endianness of its memory layout is given by the type parameter O.

An I128 can be constructed using the new method, and its contained value can be obtained as a native i128 using the get method, or updated in place with the set method. In all cases, if the endianness O is not the same as the endianness of the current platform, an endianness swap will be performed in order to uphold the invariants that a) the layout of I128 has endianness O and that, b) the layout of i128 has the platform's native endianness.

I128 implements Zeroable, and Pod, making it useful for parsing and serialization.

Implementations

impl<O: ByteOrder> I128<O>[src]

pub fn new(n: i128) -> I128<O>[src]

Constructs a new value, possibly performing an endianness swap to guarantee that the returned value has endianness O.

pub fn get(self) -> i128[src]

Returns the value as a primitive type, possibly performing an endianness swap to guarantee that the return value has the endianness of the native platform.

pub fn set(&mut self, n: i128)[src]

Updates the value in place as a primitive type, possibly performing an endianness swap to guarantee that the stored value has the endianness O.