[][src]Struct heed_types::integer::I64

#[repr(transparent)]pub struct I64<O: ByteOrder>(_, _);

A 64-bit signed integer stored in O byte order.

I64 is like the native i64 type with two major differences: First, it has no alignment requirement (its alignment is 1). Second, the endianness of its memory layout is given by the type parameter O.

An I64 can be constructed using the new method, and its contained value can be obtained as a native i64 using the get method, or updated in place with the set method. In all cases, if the endianness O is not the same as the endianness of the current platform, an endianness swap will be performed in order to uphold the invariants that a) the layout of I64 has endianness O and that, b) the layout of i64 has the platform's native endianness.

I64 implements Zeroable, and Pod, making it useful for parsing and serialization.

Implementations

impl<O: ByteOrder> I64<O>[src]

pub fn new(n: i64) -> I64<O>[src]

Constructs a new value, possibly performing an endianness swap to guarantee that the returned value has endianness O.

pub fn get(self) -> i64[src]

Returns the value as a primitive type, possibly performing an endianness swap to guarantee that the return value has the endianness of the native platform.

pub fn set(&mut self, n: i64)[src]

Updates the value in place as a primitive type, possibly performing an endianness swap to guarantee that the stored value has the endianness O.