[][src]Struct heed_types::integer::U128

#[repr(transparent)]pub struct U128<O: ByteOrder>(_, _);

A 128-bit unsigned integer stored in O byte order.

U128 is like the native u128 type with two major differences: First, it has no alignment requirement (its alignment is 1). Second, the endianness of its memory layout is given by the type parameter O.

A U128 can be constructed using the new method, and its contained value can be obtained as a native u128 using the get method, or updated in place with the set method. In all cases, if the endianness O is not the same as the endianness of the current platform, an endianness swap will be performed in order to uphold the invariants that a) the layout of U128 has endianness O and that, b) the layout of u128 has the platform's native endianness.

U128 implements Zeroable, and Pod, making it useful for parsing and serialization.

Implementations

impl<O: ByteOrder> U128<O>[src]

pub fn new(n: u128) -> U128<O>[src]

Constructs a new value, possibly performing an endianness swap to guarantee that the returned value has endianness O.

pub fn get(self) -> u128[src]

Returns the value as a primitive type, possibly performing an endianness swap to guarantee that the return value has the endianness of the native platform.

pub fn set(&mut self, n: u128)[src]

Updates the value in place as a primitive type, possibly performing an endianness swap to guarantee that the stored value has the endianness O.