[−][src]Struct heed_types::integer::U32
A 32-bit unsigned integer
stored in O byte order.
U32 is like the native u32 type with
two major differences: First, it has no alignment requirement (its alignment is 1).
Second, the endianness of its memory layout is given by the type parameter O.
A U32 can be constructed using
the new method, and its contained value can be obtained as a native
u32 using the get method, or updated in place with
the set method. In all cases, if the endianness O is not the same as the
endianness of the current platform, an endianness swap will be performed in
order to uphold the invariants that a) the layout of U32
has endianness O and that, b) the layout of u32 has
the platform's native endianness.
U32 implements Zeroable, and Pod,
making it useful for parsing and serialization.
Implementations
impl<O: ByteOrder> U32<O>[src]
pub fn new(n: u32) -> U32<O>[src]
Constructs a new value, possibly performing an endianness swap
to guarantee that the returned value has endianness O.
pub fn get(self) -> u32[src]
Returns the value as a primitive type, possibly performing an endianness swap to guarantee that the return value has the endianness of the native platform.
pub fn set(&mut self, n: u32)[src]
Updates the value in place as a primitive type, possibly
performing an endianness swap to guarantee that the stored value
has the endianness O.