[−][src]Struct heed_types::CowSlice
Describes a slice that must be memory aligned and will be reallocated if it is not.
A Cow type is returned to represent this behavior.
If you need to store a slice that doesn't depends on any
memory alignment it is recommended to use the UnalignedSlice.
if you don't want to be bored with the Cow type you can
use the OwnedSlice.