[−][src]Struct heed_types::CowType
Describes a type that must be memory aligned and will be reallocated if it is not.
A Cow type is returned to represent this behavior.
If you need to store a type that doesn't depends on any
memory alignment it is recommended to use the UnalignedType.
If you don't want to be bored with the Cow type you can
use the OwnedType.
To store slices, you must look at the CowSlice,
OwnedSlice or UnalignedSlice types.