[−][src]Struct heed_types::OwnedType
Describes a type that is totally owned (doesn't hold any reference to the original slice).
If you need to store a type that doesn't depends on any
memory alignment and that can be big it is recommended
to use the UnalignedType.
The CowType is recommended for borrowed types (types that holds
references to the original slice).
To store slices, you must look at the CowSlice,
OwnedSlice or UnalignedSlice types.