[−][src]Struct heed_types::integer::I16
A 16-bit signed integer
stored in O byte order.
I16 is like the native i16 type with
two major differences: First, it has no alignment requirement (its alignment is 1).
Second, the endianness of its memory layout is given by the type parameter O.
An I16 can be constructed using
the new method, and its contained value can be obtained as a native
i16 using the get method, or updated in place with
the set method. In all cases, if the endianness O is not the same as the
endianness of the current platform, an endianness swap will be performed in
order to uphold the invariants that a) the layout of I16
has endianness O and that, b) the layout of i16 has
the platform's native endianness.
I16 implements Zeroable, and Pod,
making it useful for parsing and serialization.
Implementations
impl<O: ByteOrder> I16<O>[src]
pub fn new(n: i16) -> I16<O>[src]
Constructs a new value, possibly performing an endianness swap
to guarantee that the returned value has endianness O.
pub fn get(self) -> i16[src]
Returns the value as a primitive type, possibly performing an endianness swap to guarantee that the return value has the endianness of the native platform.
pub fn set(&mut self, n: i16)[src]
Updates the value in place as a primitive type, possibly
performing an endianness swap to guarantee that the stored value
has the endianness O.